"""Nightly schedule for validating all active Routers' configuration."""

import logging

from orchestrator.schedules.scheduling import scheduler
from orchestrator.services.processes import start_process

from gso.services.subscriptions import get_active_router_subscriptions

logger = logging.getLogger(__name__)


@scheduler(name="Validate routers", time_unit="day", at="03:00")
def run_validate_routers() -> None:
    """Validate configuration on all active Routers, every night at 3AM."""
    routers = get_active_router_subscriptions(includes=["subscription_id"])

    for router in routers:
        msg = f"Validating configuration of router subscription {router['subscription_id']}"
        logger.info(msg)
        start_process("validate_router", [{"subscription_id": router["subscription_id"]}])
